@@ -180,6 +180,24 @@ class Eos:
             block_num
         )
         response = muterun_js(self.current_dir + '/js/GetBlock.js', arguments=arguments)
+        if response.exitcode == 0:
+            data = self.load_data(response.stdout)
+            return data
+        else:
+            raise GetAccountException(response.stderr)
+
+    def deserialize_action_data (self, c_abi_hex, c_account, act_name, act_data_hex):
+        """
+        Deserializes action data based on a specific contract abi.
+        """
+        arguments = "'%s' '%s' '%s' '%s' '%s'" % (
+            self.http_address,
+            c_abi_hex,
+            c_account,
+            act_name,
+            act_data_hex
+        )
+        response = muterun_js(self.current_dir + '/js/Deserializer.js', arguments=arguments)
         if response.exitcode == 0:
             data = self.load_data(response.stdout)
             return data
